---
title: <span class="badge builder"></span> TimeRange
---
# <span class="badge builder"></span> TimeRange

## Constructor

```python
TimeRange()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> alerting.TimeRange
```

### <span class="badge object-method"></span> from_val

```python
def from_val(from_val: str) -> typing.Self
```

### <span class="badge object-method"></span> to

```python
def to(to: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TimeRange](./object-TimeRange.md)
